#
# spec file for package laszip
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2019 Bruno Friedmann, Ioda-Net Sàrl, Charmoille, Switzerland.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover 8
Name:           laszip
Version:        3.4.3
Release:        bp155.2.12
Summary:        Compression library supporting ASPRS LAS format data
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://laszip.org/
Source0:        https://github.com/LASzip/LASzip/releases/download/%{version}/laszip-src-%{version}.tar.gz
Source1:        https://github.com/LASzip/LASzip/releases/download/%{version}/laszip-src-%{version}.tar.gz.sha256sum
BuildRequires:  cmake
BuildRequires:  gcc-c++

%description
A free product of rapidlasso GmbH - quickly turns bulky LAS files into
compact LAZ files without information loss. LASzip is a compression library that
was developed by Martin Isenburg for compressing ASPRS LAS format data in his
LAStools. It has been provided as an LGPL-licensed stand-alone software library
to allow other softwares that handle LAS data to read and write LASzip-compressed
data. The BSD-licensed libLAS and the LGPL-licensed LASlib can take advantage of
LASzip to read and write compressed data.

%package -n lib%{name}%{sover}
Summary:        Library files for %{name}
Group:          System/Libraries

%description -n lib%{name}%{sover}
A free product of rapidlasso GmbH - quickly turns bulky LAS files into
compact LAZ files without information loss. LASzip is a compression library that
was developed by Martin Isenburg for compressing ASPRS LAS format data in his
LAStools. It has been provided as an LGPL-licensed stand-alone software library
to allow other softwares that handle LAS data to read and write LASzip-compressed
data. The BSD-licensed libLAS and the LGPL-licensed LASlib can take advantage of
LASzip to read and write compressed data.

This package contain only the dynamic build.

%package -n lib%{name}_api%{sover}
Summary:        API library files for lib%{name}
# Packager comment are we sure this api can live alone ?
#Requires:       lib%%{name}%%{sover} = %%{version}
Group:          System/Libraries

%description -n lib%{name}_api%{sover}
API library for %{name}
This package contain only the dynamic build.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{sover} = %{version}
Requires:       lib%{name}_api%{sover} = %{version}

%description devel
Headers and development files for %{name} needed to develop
softwares that handle LAS data to read and write LASzip-compressed
data.

%prep
%setup -q -n laszip-src-%{version}

%build
# laszip need dlopen,dlsym,dlclose
%cmake \
    -DCMAKE_SKIP_RPATH:BOOL=ON \
    -DCMAKE_C_FLAGS="%{optflags} -fno-strict-aliasing -fPIC" \
    -DCMAKE_C_FLAGS_RELWITHDEBINFO="%{optflags} -fno-strict-aliasing -fPIC" \
    -DCMAKE_CXX_FLAGS="%{optflags} -fno-strict-aliasing -fPIC" \
    -DCMAKE_CXX_FLAGS_RELWITHDEBINFO="%{optflags} -fno-strict-aliasing -fPIC" \
    -DCMAKE_SHARED_LINKER_FLAGS="-Wl,--as-needed -Wl,--no-undefined -Wl,-z,now -Wl,--no-as-needed -ldl"

%cmake_build

%install
%cmake_install

%post -n lib%{name}%{sover} -p /sbin/ldconfig
%postun -n lib%{name}%{sover}  -p /sbin/ldconfig
%post -n lib%{name}_api%{sover} -p /sbin/ldconfig
%postun -n lib%{name}_api%{sover}  -p /sbin/ldconfig

%files devel
%license COPYING
%doc ChangeLog AUTHORS
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/%{name}_api_version.h
%{_includedir}/%{name}/%{name}_api.h
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}_api.so

%files -n lib%{name}%{sover}
%doc ChangeLog AUTHORS
%license COPYING
%{_libdir}/lib%{name}.so.*

%files -n lib%{name}_api%{sover}
%doc ChangeLog AUTHORS
%license COPYING
%{_libdir}/lib%{name}_api.so.*

%changelog
* Mon May 18 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 3.4.3:
  * UTF16 filename support and windows unicode support
  * Fix extra_bytes selective decompression PDAL/PDAL#2799 #62
  * Compatibility mode fix #60
* Tue Mar 24 2020 Max Lin <mlin@suse.com>
- Disable RPATH for building
* Wed Jul 10 2019 Dirk Stoecker <opensuse@dstoecker.de>
- update to version 3.4.1
  * 1024 AC_BUFFER_SIZE to 4096 for propagate_carry() overflow
  * Fix two small memory leaks
  * FastAC now properly BSD-licensed.
  * writer: sanity check for consistent legacy and extended classification
  * reader: zero the legacy classification whenever extended classification
    is larger than 31
  * bug fix when writing 4,294,967,296 or more points uncompressed to LAS
  * fix for LASzip v4 decompression of WavePacket part of PRDF 9 and 10
  * upped to 3.2 r9 for bug fix in multi-channel NIR decompression
  * fix for v4 decompression of WavePacket part of PRDF 9 and 10
- build fix: use -fPIC instead of -fPIE for library
* Tue Feb 19 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to 3.2.9 version
  + Decompression bug for PRDF 8 or 10 when the scanner channel
    and the NIR field are populated.
  + 3.2.8 **NOTE: The version number is 3.2.8 to be brought in line
    with the patch version number present in LAStools, which had
    been incremented without being kept in sync with the laszip.org
    version. We regret the error.
    bug fixes since 3.2.2:
    + 7 November 2018 upped to 3.2 r8 for identical legacy and
    extended flags check
    + 20 October 2018 upped to 3.2 r7 for rare bug in
    LASinterval::merge_intervals()
    + 5 October 2018 upped to 3.2 r6 for corrected 'is_empty'
    return value
    + 28 September 2018 upped to 3.2 r5 for fix in extended
    classification writing
  + 3.2.2
    + A version number was not properly incremented to 3.2.1,
    necessitating a new release to eliminate confusion.
  + 3.2.1
    + Library SOVERSIONing for libtool to 8.0.0 #36
    + Update NEWS and ChangeLog
    + Library version inadvertently had major version in name
    (only relevant on windows)
    + Now building on AppVeyor and Travis
  + 3.2.0
    + Fix install of laszip_api_version.h #30
    + Add V4 read methods
- Packaging
  + minimal spec-cleaner (date/url) + trailing space in changes
  + remove merged upstream 0bf1c60.patch
  + adjust path of laszip_api_version.h to /usr/include/laszip
* Wed Jan 24 2018 bruno@ioda-net.ch
- Packaging :
  + Remove -test package and %%check section, tests are no more
    autoincluded by upstream
  + Adjust FLAGS laszip need -ldl, and be sure %%optflags are used
  + Create new liblas_api package
  + Fix list of file
  + Use %%license if possible
  + move to cmake build following upstream
  + Added 0bf1c60.patch fixing .so loading
- Update to 3.1.1 version.
  + sover change from 6 to 3
  + 3.1.0 introduce support for LAZ 1.4
  + New "dll" API replace previous API
  + See all changes in Changelog
* Wed Jul  6 2016 mpluskal@suse.com
- Small spec file cleanup:
  * move check to proper section
  * simplify buildconditions a bit
  * run spec-cleaner
  * reduce amount of build dependencies
* Thu Feb 12 2015 mpluskal@suse.com
- Cleanup specfile:
  * remove dependency on make
  * remove dependency on own lib (at it is generated automatically)
  * do not use excessive %%defines as this is not necessary
  * move test to separate package
  * remove %%check section as it is not checking anything, just
    building test.
- Use autoreconf to prevent random build failures
* Fri Aug 22 2014 bruno@ioda-net.ch
- Added security compil flag for >13.1
- spec clean
- rename package to without caps
- make lib using share lib policy
* Thu Aug 21 2014 bruno@ioda-net.ch
- First packaging for obs, LASzip is needed to have full support
  of compressed las into other software
